diff src/popupwin.c @ 19542:9e428147e4ee v8.2.0328

patch 8.2.0328: no redraw when leaving term-normal mode in popup terminal Commit: https://github.com/vim/vim/commit/e52e0c89d1a6305beca3c01f89a4892dcb43bc71 Author: Bram Moolenaar <Bram@vim.org> Date: Fri Feb 28 22:20:10 2020 +0100 patch 8.2.0328: no redraw when leaving term-normal mode in popup terminal Problem: No redraw when leaving terminal-normal mode in a terminal popup window. Solution: Redraw the popup window. (closes #5708)
author Bram Moolenaar <Bram@vim.org>
date Fri, 28 Feb 2020 22:30:09 +0100
parents 9f07a6c172f2
children 167181848770
line wrap: on
line diff
--- a/src/popupwin.c
+++ b/src/popupwin.c
@@ -3505,9 +3505,12 @@ update_popups(void (*win_update)(win_T *
 
 	wp->w_winrow -= top_off;
 	wp->w_wincol -= left_extra;
-	// cursor position matters in terminal
-	wp->w_wrow += top_off;
-	wp->w_wcol += left_extra;
+	// cursor position matters in terminal in job mode
+	if (wp != curwin || !term_in_normal_mode())
+	{
+	    wp->w_wrow += top_off;
+	    wp->w_wcol += left_extra;
+	}
 
 	total_width = popup_width(wp);
 	total_height = popup_height(wp);